==> netbeans_8.0.2%2Bdfsg1.orig.tar.xz: netbeans-8.0.2/core.output2/src/org/netbeans/core/output2/OutputLimits.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */
package org.netbeans.core.output2;

/**
 * Specifies limit values for Output Window.
 *
 * @author jhavlin
 */
public class OutputLimits {

    private final int maxLines;
    private final int maxChars;
    private final int removeLines;
    private static final OutputLimits DEFAULT = new OutputLimits();

    /**
     * Constructor for custom output limits.
     *
     * @param maxLines Limit for number of lines.
     * @param maxChars Limit for number of characters.
     * @param removeLines How many oldest lines should be removed if one of the
     * limits is reached (but at most half of the current lines will be
     * removed).
     */
    public OutputLimits(int maxLines, int maxChars, int removeLines) {
        this.maxLines = maxLines;
        this.maxChars = maxChars;
        this.removeLines = removeLines;
    }

    /**
     * Constructor for default output limits: 4 million lines (2^22), 1 billion
     * characters (2^30), remove 2 million lines (2^21) if a limit is reached.
     */
    private OutputLimits() {
        this(4194304, Integer.MAX_VALUE / 2, 2097152);
    }

    public int getMaxLines() {
        return maxLines;
    }

    public int getMaxChars() {
        return maxChars;
    }

    public int getRemoveLines() {
        return removeLines;
    }

    /**
     * Get default output limits: 4 million lines (2^22), 1 billion characters
     * (2^30), remove 2 million lines (2^21) if a limit is reached.
     */
    public static OutputLimits getDefault() {
        return DEFAULT;
    }
}

==> netbeans_8.2%2Bdfsg1.orig.tar.xz: netbeans-8.2/core.output2/src/org/netbeans/core/output2/OutputLimits.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */
package org.netbeans.core.output2;

/**
 * Specifies limit values for Output Window.
 *
 * @author jhavlin
 */
public class OutputLimits {

    private final int maxLines;
    private final int maxChars;
    private final int removeLines;
    private static final OutputLimits DEFAULT = new OutputLimits();

    /**
     * Constructor for custom output limits.
     *
     * @param maxLines Limit for number of lines.
     * @param maxChars Limit for number of characters.
     * @param removeLines How many oldest lines should be removed if one of the
     * limits is reached (but at most half of the current lines will be
     * removed).
     */
    public OutputLimits(int maxLines, int maxChars, int removeLines) {
        this.maxLines = maxLines;
        this.maxChars = maxChars;
        this.removeLines = removeLines;
    }

    /**
     * Constructor for default output limits: 4 million lines (2^22), 512
     * million characters (2^29), remove 2 million lines (2^21) if a limit is
     * reached.
     */
    private OutputLimits() {
        this(4194304, Integer.MAX_VALUE / 4, 2097152);
    }

    public int getMaxLines() {
        return maxLines;
    }

    public int getMaxChars() {
        return maxChars;
    }

    public int getRemoveLines() {
        return removeLines;
    }

    /**
     * Get default output limits: 4 million lines (2^22), 1 billion characters
     * (2^30), remove 2 million lines (2^21) if a limit is reached.
     */
    public static OutputLimits getDefault() {
        return DEFAULT;
    }
}
